@@ -307,6 +307,7 @@ class GithubUtilsApi:
         :param sort: string; Can be one of created, updated, pushed, full_name. Default: created
         :param per_page: integer; Results per page (max 100). Default: 30
         :return: Array of repositories
+        TODO: Pending refactor with recursive approach to increase legibility and performance
         """
         page = 1
         result = self._response_to_json(
@@ -365,8 +366,10 @@ class GithubUtilsApi:
         url = self.github_url + "/repos/" + owner + "/" + repository_name + "/branches" + query
         return self._request("GET", url, params)
 
+    @PendingDeprecationWarning
     def list_repository_branches_all(self, owner=None, repository_name=None, protected=None, per_page=30):
         """
+        DEPRECATED!
         This method allows listing all branches in a repository, without paginate option using the method self.list_repository_branches.
         According API docs: https://docs.github.com/es/rest/reference/branches#list-branches
         :param owner: string; name of the current organization created at GitHub or the owner
@@ -509,6 +512,7 @@ class GithubUtilsApi:
         :param repository_name: string; repository slug name
         :param per_page: integer; Results per page (max 100). Default: 30
         :return: Array of Teams
+        TODO: This method is not working properly, it is not returning all teams
         """
         page = 1
         result = self._response_to_json(
